summaryrefslogtreecommitdiff
path: root/cryptlib.h
diff options
context:
space:
mode:
authorJeffrey Walton <noloader@gmail.com>2019-08-16 07:12:14 -0400
committerJeffrey Walton <noloader@gmail.com>2019-08-16 07:12:14 -0400
commite22700f741af9071b166a74dd904a1bb7910c6b9 (patch)
treea743990feaa3aa5735dc3475e1acdca2800c2215 /cryptlib.h
parentc0a5a06a8285c515336a7540095d75aaad628644 (diff)
downloadcryptopp-git-e22700f741af9071b166a74dd904a1bb7910c6b9.tar.gz
Fix use of MaxDerivedKeyLength (GH #874)
Diffstat (limited to 'cryptlib.h')
-rw-r--r--cryptlib.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/cryptlib.h b/cryptlib.h
index b1f5a71b..7e105a3c 100644
--- a/cryptlib.h
+++ b/cryptlib.h
@@ -1503,7 +1503,7 @@ public:
/// \param secretLen the size of the secret buffer, in bytes
/// \param params additional initialization parameters to configure this object
/// \returns the number of iterations performed
/// \throws InvalidDerivedLength if <tt>derivedLen</tt> is invalid for the scheme
/// \details DeriveKey() provides a standard interface to derive a key from
/// a secret seed and other parameters. Each class that derives from KeyDerivationFunction
/// provides an overload that accepts most parameters used by the derivation function.
@@ -1525,7 +1525,7 @@ protected:
/// \brief Validates the derived key length
/// \param length the size of the derived key material, in bytes
/// \throws InvalidKeyLength if the key length is invalid
- void ThrowIfInvalidDerivedLength(size_t length) const;
+ void ThrowIfInvalidDerivedKeyLength(size_t length) const;
};
/// \brief Interface for password based key derivation functions
@@ -1503,7 +1503,7 @@ public:
/// \param params additional initialization parameters to configure this object
/// \returns the number of iterations performed
- /// \throws InvalidDerivedLength if <tt>derivedLen</tt> is invalid for the scheme
+ /// \throws InvalidDerivedKeyLength if <tt>derivedLen</tt> is invalid for the scheme
/// \details DeriveKey() provides a standard interface to derive a key from
/// a secret seed and other parameters. Each class that derives from KeyDerivationFunction